@@ -23,13 +23,12 @@
 #define KEYFRAMEIMPORT_H
 
 #include <QDialog>
-#include <QPixmap>
 #include <QLabel>
 
 #include "definitions.h"
 #include "timecode.h"
 
-class PositionEdit;
+class PositionWidget;
 class QCheckBox;
 class QSpinBox;
 class KeyframeView;
@@ -38,7 +37,7 @@ class KeyframeImport : public QDialog
 {
     Q_OBJECT
 public:
-    explicit KeyframeImport(ItemInfo srcInfo, ItemInfo dstInfo, QMap<QString, QString> data, const Timecode &tc, QDomElement xml, ProfileInfo profile, QWidget *parent = 0);
+    explicit KeyframeImport(const ItemInfo &srcInfo, const ItemInfo &dstInfo, const QMap<QString, QString> &data, const Timecode &tc, const QDomElement &xml, const ProfileInfo &profile, QWidget *parent = nullptr);
     virtual ~KeyframeImport();
     QString selectedData() const;
     QString selectedTarget() const;
@@ -50,9 +49,9 @@ private:
     QComboBox *m_dataCombo;
     QLabel *m_previewLabel;
     KeyframeView *m_keyframeView;
-    PositionEdit *m_inPoint;
-    PositionEdit *m_outPoint;
-    PositionEdit *m_offsetPoint;
+    PositionWidget *m_inPoint;
+    PositionWidget *m_outPoint;
+    PositionWidget *m_offsetPoint;
     QCheckBox *m_limitRange;
     QCheckBox *m_limitKeyframes;
     QSpinBox *m_limitNumber;
@@ -60,16 +59,16 @@ private:
     QComboBox *m_targetCombo;
     QComboBox *m_alignCombo;
     QLabel *m_sourceRangeLabel;
-    QList <QPoint> m_maximas;
+    QList<QPoint> m_maximas;
     QDoubleSpinBox m_destMin;
     QDoubleSpinBox m_destMax;
     /** @brief Contains the 4 dimensional (x,y,w,h) target parameter names / tag **/
-    QMap <QString, QString> m_geometryTargets;
+    QMap<QString, QString> m_geometryTargets;
     /** @brief Contains the 1 dimensional target parameter names / tag **/
-    QMap <QString, QString> m_simpleTargets;
+    QMap<QString, QString> m_simpleTargets;
 
 protected:
-    void resizeEvent(QResizeEvent *ev);
+    void resizeEvent(QResizeEvent *ev) Q_DECL_OVERRIDE;
 
 private slots:
     void updateDataDisplay();
