@@ -26,7 +26,9 @@
 #include "kxmlgui_version.h"
 
 #include <KAboutData>
+#ifdef KF5_USE_CRASH
 #include <KCrash>
+#endif
 #include <KIconLoader>
 #include <KSharedConfig>
 #include <KConfigGroup>
@@ -65,6 +67,7 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kdenlive"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
+    app.setDesktopFileName(QStringLiteral("org.kde.kdenlive"));
     app.setWindowIcon(QIcon(QStringLiteral(":/pics/kdenlive.png")));
     KLocalizedString::setApplicationDomain("kdenlive");
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -142,7 +145,9 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+#ifdef KF5_USE_CRASH
     KCrash::initialize();
+#endif
 
     QString clipsToLoad = parser.value(QStringLiteral("i"));
     QString mltPath = parser.value(QStringLiteral("mlt-path"));
