@@ -25,34 +25,34 @@
 #ifndef SPECTROGRAM_H
 #define SPECTROGRAM_H
 
-
 #include "abstractaudioscopewidget.h"
 #include "ui_spectrogram_ui.h"
 #include "lib/audio/fftTools.h"
 
 class Spectrogram_UI;
-class Spectrogram : public AbstractAudioScopeWidget {
+class Spectrogram : public AbstractAudioScopeWidget
+{
     Q_OBJECT
 
 public:
-    explicit Spectrogram(QWidget *parent = 0);
+    explicit Spectrogram(QWidget *parent = nullptr);
     ~Spectrogram();
 
-    QString widgetName() const;
+    QString widgetName() const Q_DECL_OVERRIDE;
 
 protected:
     ///// Implemented methods /////
-    QRect scopeRect();
-    QImage renderHUD(uint accelerationFactor);
-    QImage renderAudioScope(uint accelerationFactor, const audioShortVector &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData);
-    QImage renderBackground(uint accelerationFactor);
-    bool isHUDDependingOnInput() const;
-    bool isScopeDependingOnInput() const;
-    bool isBackgroundDependingOnInput() const;
-    virtual void readConfig();
+    QRect scopeRect() Q_DECL_OVERRIDE;
+    QImage renderHUD(uint accelerationFactor) Q_DECL_OVERRIDE;
+    QImage renderAudioScope(uint accelerationFactor, const audioShortVector &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData) Q_DECL_OVERRIDE;
+    QImage renderBackground(uint accelerationFactor) Q_DECL_OVERRIDE;
+    bool isHUDDependingOnInput() const Q_DECL_OVERRIDE;
+    bool isScopeDependingOnInput() const Q_DECL_OVERRIDE;
+    bool isBackgroundDependingOnInput() const Q_DECL_OVERRIDE;
+    void readConfig() Q_DECL_OVERRIDE;
     void writeConfig();
-    void handleMouseDrag(const QPoint &movement, const RescaleDirection rescaleDirection, const Qt::KeyboardModifiers rescaleModifiers);
-    void resizeEvent(QResizeEvent *event);
+    void handleMouseDrag(const QPoint &movement, const RescaleDirection rescaleDirection, const Qt::KeyboardModifiers rescaleModifiers) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
 private:
     Ui::Spectrogram_UI *ui;
