@@ -22,7 +22,6 @@ Histogram::Histogram(QWidget *parent) :
     ui = new Ui::Histogram_UI();
     ui->setupUi(this);
 
-
     m_aUnscaled = new QAction(i18n("Unscaled"), this);
     m_aUnscaled->setCheckable(true);
 
@@ -40,11 +39,11 @@ Histogram::Histogram(QWidget *parent) :
     m_menu->addAction(m_aRec601);
     m_menu->addAction(m_aRec709);
 
-    connect(ui->cbY, SIGNAL(toggled(bool)), this, SLOT(forceUpdateScope()));
-    connect(ui->cbS, SIGNAL(toggled(bool)), this, SLOT(forceUpdateScope()));
-    connect(ui->cbR, SIGNAL(toggled(bool)), this, SLOT(forceUpdateScope()));
-    connect(ui->cbG, SIGNAL(toggled(bool)), this, SLOT(forceUpdateScope()));
-    connect(ui->cbB, SIGNAL(toggled(bool)), this, SLOT(forceUpdateScope()));
+    connect(ui->cbY, &QAbstractButton::toggled, this, &AbstractScopeWidget::forceUpdateScope);
+    connect(ui->cbS, &QAbstractButton::toggled, this, &AbstractScopeWidget::forceUpdateScope);
+    connect(ui->cbR, &QAbstractButton::toggled, this, &AbstractScopeWidget::forceUpdateScope);
+    connect(ui->cbG, &QAbstractButton::toggled, this, &AbstractScopeWidget::forceUpdateScope);
+    connect(ui->cbB, &QAbstractButton::toggled, this, &AbstractScopeWidget::forceUpdateScope);
     connect(m_aUnscaled, &QAction::toggled, this, &Histogram::forceUpdateScope);
     connect(m_aRec601, &QAction::toggled, this, &Histogram::forceUpdateScope);
     connect(m_aRec709, &QAction::toggled, this, &Histogram::forceUpdateScope);
@@ -97,14 +96,23 @@ QString Histogram::widgetName() const
     return QStringLiteral("Histogram");
 }
 
-bool Histogram::isHUDDependingOnInput() const { return false; }
-bool Histogram::isScopeDependingOnInput() const { return true; }
-bool Histogram::isBackgroundDependingOnInput() const { return false; }
+bool Histogram::isHUDDependingOnInput() const
+{
+    return false;
+}
+bool Histogram::isScopeDependingOnInput() const
+{
+    return true;
+}
+bool Histogram::isBackgroundDependingOnInput() const
+{
+    return false;
+}
 
 QRect Histogram::scopeRect()
 {
-    //qDebug() << "According to the spacer, the top left point is " << ui->verticalSpacer->geometry().x() << '/' << ui->verticalSpacer->geometry().y();
-    QPoint topleft(offset, offset+ ui->verticalSpacer->geometry().y());
+    //qCDebug(KDENLIVE_LOG) << "According to the spacer, the top left point is " << ui->verticalSpacer->geometry().x() << '/' << ui->verticalSpacer->geometry().y();
+    QPoint topleft(offset, offset + ui->verticalSpacer->geometry().y());
     return QRect(topleft, this->rect().size() - QSize(topleft.x() + offset, topleft.y() + offset));
 }
 
@@ -117,7 +125,7 @@ QImage Histogram::renderGfxScope(uint accelFactor, const QImage &qimage)
 {
     QTime start = QTime::currentTime();
     start.start();
-    const int componentFlags =   (ui->cbY->isChecked() ? 1 : 0) * HistogramGenerator::ComponentY
+    const int componentFlags = (ui->cbY->isChecked() ? 1 : 0) * HistogramGenerator::ComponentY
                                | (ui->cbS->isChecked() ? 1 : 0) * HistogramGenerator::ComponentSum
                                | (ui->cbR->isChecked() ? 1 : 0) * HistogramGenerator::ComponentR
                                | (ui->cbG->isChecked() ? 1 : 0) * HistogramGenerator::ComponentG
@@ -126,7 +134,7 @@ QImage Histogram::renderGfxScope(uint accelFactor, const QImage &qimage)
     HistogramGenerator::Rec rec = m_aRec601->isChecked() ? HistogramGenerator::Rec_601 : HistogramGenerator::Rec_709;
 
     QImage histogram = m_histogramGenerator->calculateHistogram(m_scopeRect.size(), qimage, componentFlags,
-                                                                rec, m_aUnscaled->isChecked(), accelFactor);
+                       rec, m_aUnscaled->isChecked(), accelFactor);
 
     emit signalScopeRenderingFinished(start.elapsed(), accelFactor);
     return histogram;
@@ -137,4 +145,3 @@ QImage Histogram::renderBackground(uint)
     return QImage();
 }
 
-
